==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropMerge.h <==
// public final class soot.jimple.spark.solver.PropMerge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46dd324adffb807c soot_jimple_spark_solver_PropMerge
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropMerge_H_
#define _JC_soot_jimple_spark_solver_PropMerge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropMerge$sub_refs	_jc_soot_jimple_spark_solver_PropMerge$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs	_jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$refs	_jc_soot_jimple_spark_solver_PropMerge$refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$nonrefs	_jc_soot_jimple_spark_solver_PropMerge$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$object	_jc_soot_jimple_spark_solver_PropMerge$object;

typedef const struct _jc_soot_jimple_spark_solver_PropMerge$vmethods	_jc_soot_jimple_spark_solver_PropMerge$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge$vtable	_jc_soot_jimple_spark_solver_PropMerge$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge$vtype	_jc_soot_jimple_spark_solver_PropMerge$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropMerge$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropMerge$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropMerge$method$handleVarNode$38f043a08670ae06(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern void _jc_soot_jimple_spark_solver_PropMerge$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge$method_info$handleVarNode$38f043a08670ae06;
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropMerge$vmethods {
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	jboolean	(*handleVarNode$38f043a08670ae06)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropMerge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropMerge$vmethods	soot_jimple_spark_solver_PropMerge;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropMerge$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropMerge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge$sub_refs {
	struct _jc_object	*varNodeWorkList;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge$refs {
    _jc_soot_jimple_spark_solver_PropMerge$sub_refs	soot_jimple_spark_solver_PropMerge;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs	soot_jimple_spark_solver_PropMerge;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropMerge$object {
	_jc_soot_jimple_spark_solver_PropMerge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropMerge$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropMerge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropMerge$vtype _jc_soot_jimple_spark_solver_PropMerge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropMerge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropMerge$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropMerge_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropMerge.h <==
// public final class soot.jimple.spark.solver.PropMerge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 46dd324adffb807c soot_jimple_spark_solver_PropMerge
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropMerge_H_
#define _JC_soot_jimple_spark_solver_PropMerge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropMerge$sub_refs	_jc_soot_jimple_spark_solver_PropMerge$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs	_jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$refs	_jc_soot_jimple_spark_solver_PropMerge$refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$nonrefs	_jc_soot_jimple_spark_solver_PropMerge$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge$object	_jc_soot_jimple_spark_solver_PropMerge$object;

typedef const struct _jc_soot_jimple_spark_solver_PropMerge$vmethods	_jc_soot_jimple_spark_solver_PropMerge$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge$vtable	_jc_soot_jimple_spark_solver_PropMerge$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge$vtype	_jc_soot_jimple_spark_solver_PropMerge$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropMerge$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropMerge$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropMerge$method$handleVarNode$38f043a08670ae06(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_PropMerge$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge$method_info$handleVarNode$38f043a08670ae06;
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropMerge$vmethods {
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	jboolean	(*handleVarNode$38f043a08670ae06)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropMerge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropMerge$vmethods	soot_jimple_spark_solver_PropMerge;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropMerge$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropMerge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge$sub_refs {
	struct _jc_object	*varNodeWorkList;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge$refs {
    _jc_soot_jimple_spark_solver_PropMerge$sub_refs	soot_jimple_spark_solver_PropMerge;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropMerge$sub_nonrefs	soot_jimple_spark_solver_PropMerge;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropMerge$object {
	_jc_soot_jimple_spark_solver_PropMerge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropMerge$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropMerge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropMerge$vtype _jc_soot_jimple_spark_solver_PropMerge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropMerge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropMerge$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropMerge_H_ */
